pub struct AuthLayer { /* private fields */ }Expand description
Auth middleware that manages Authorization headers.
Implementations
Sourceimpl AuthLayer
impl AuthLayer
pub fn new(strategy: AuthStrategy) -> Self
Sourcepub fn static_bearer(token: impl Into<String>) -> Self
pub fn static_bearer(token: impl Into<String>) -> Self
Create an auth layer that injects a static bearer token.
Sourcepub fn passthrough() -> Self
pub fn passthrough() -> Self
Create an auth layer that passes through client auth.