pub type InboundConnection = (ProxyRequest, Sender<ProxyResponse>);Expand description
A connection received by a listener: the request plus a channel to send the response back.
pub type InboundConnection = (ProxyRequest, Sender<ProxyResponse>);A connection received by a listener: the request plus a channel to send the response back.