Module types

Module types 

Structs

Extensions
Type-safe extension map for attaching arbitrary metadata to requests/responses.
FormatId
Identifier for a body format used by the conversion system.
ProxyRequest
A request flowing through the proxy.
ProxyResponse
A response flowing back through the proxy.

Enums

ProxyBody
Body payload for proxied messages.
TransportKind
The transport protocol over which a request arrived.